package com.company.sample1.app

import com.company.sample1.entity.Case
import com.company.sample1.entity.LegalPerson
import com.company.sample1.entity.NaturalPerson
import io.jmix.core.DataManager
import io.jmix.ui.model.DataContext
import org.springframework.beans.factory.annotation.Autowired
import org.springframework.stereotype.Component
import java.util.*
import kotlin.collections.HashMap

@Component
class BaseThirdPartyEntityLoader {

    @Autowired
    private lateinit var dataManager: DataManager

    fun reloadCaseOwners(entities: List<Case>, fetchPlanName: String, dataContext: DataContext) {
        val naturalPersonIds: MutableList<UUID> = LinkedList()
        val legalPersonIds: MutableList<UUID> = LinkedList()
        val caseByOwner: MutableMap<UUID, Case> = HashMap()

        for (case in entities) {
            if (case.owner == null) continue

            if (case.owner is NaturalPerson) naturalPersonIds.add(case.owner!!.id!!)
            if (case.owner is LegalPerson) legalPersonIds.add(case.owner!!.id!!)

            caseByOwner.put(case.owner!!.id!!, case)
        }

        val naturalPersons: List<NaturalPerson> = dataManager.load(NaturalPerson::class.java)
                .ids((naturalPersonIds as Collection<*>?)!!)
                .fetchPlan(fetchPlanName)
                .list()

        val legalPersons: List<LegalPerson> = dataManager.load(LegalPerson::class.java)
                .ids((legalPersonIds as Collection<*>?)!!)
                .fetchPlan(fetchPlanName)
                .list()

        for (person in naturalPersons) caseByOwner[person.id!!]?.owner = person
        for (person in legalPersons) caseByOwner[person.id!!]?.owner = person

        dataContext.merge(naturalPersons)
        dataContext.merge(legalPersons)
    }
}